==> netbeans_6.8.orig.tar.gz: netbeans-6.8/autoupdate.ui/src/org/netbeans/modules/autoupdate/ui/actions/CheckForUpdatesAction.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.autoupdate.ui.actions;

import java.util.Collection;
import org.netbeans.modules.autoupdate.ui.PluginManagerUI;
import org.netbeans.modules.autoupdate.ui.wizards.InstallUnitWizard;
import org.netbeans.modules.autoupdate.ui.wizards.LazyInstallUnitWizardIterator.LazyUnit;
import org.netbeans.modules.autoupdate.ui.wizards.OperationWizardModel.OperationType;
import org.openide.DialogDisplayer;
import org.openide.NotifyDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle;
import org.openide.util.RequestProcessor;
import org.openide.util.actions.CallableSystemAction;

public final class CheckForUpdatesAction extends CallableSystemAction {

    public void performAction () {
        boolean wizardFinished = false;
        RequestProcessor.Task t = PluginManagerUI.getRunningTask ();
        if (t != null && ! t.isFinished ()) {
            DialogDisplayer.getDefault ().notifyLater (
                    new NotifyDescriptor.Message (
                        NbBundle.getMessage (AutoupdateCheckScheduler.class,
                            "AutoupdateCheckScheduler_InstallInProgress"), // NOI18N
                        NotifyDescriptor.WARNING_MESSAGE));
            return ;
        }
        Collection<LazyUnit> units = LazyUnit.loadLazyUnits (OperationType.UPDATE);
        try {
            wizardFinished = new InstallUnitWizard ().invokeLazyWizard (units, OperationType.UPDATE, true);
        } finally {
            if (wizardFinished) {
                PluginManagerUI pluginManagerUI = PluginManagerAction.getPluginManagerUI ();
                if (pluginManagerUI != null) {
                    pluginManagerUI.updateUnitsChanged();
                }
            }
        }
    }

    public String getName () {
        return NbBundle.getMessage (CheckForUpdatesAction.class, "CTL_CheckForUpdatesAction");
    }

    @Override
    protected void initialize () {
        super.initialize ();
        // see org.openide.util.actions.SystemAction.iconResource() Javadoc for more details
        putValue ("noIconInMenu", Boolean.TRUE);
    }

    public HelpCtx getHelpCtx () {
        return HelpCtx.DEFAULT_HELP;
    }

    @Override
    protected boolean asynchronous () {
        return false;
    }
}

==> netbeans_7.0.1+dfsg1.orig.tar.gz: netbeans-7.0.1+dfsg1/autoupdate.ui/src/org/netbeans/modules/autoupdate/ui/actions/CheckForUpdatesAction.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.autoupdate.ui.actions;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Collection;
import org.netbeans.modules.autoupdate.ui.PluginManagerUI;
import org.netbeans.modules.autoupdate.ui.wizards.InstallUnitWizard;
import org.netbeans.modules.autoupdate.ui.wizards.LazyInstallUnitWizardIterator.LazyUnit;
import org.netbeans.modules.autoupdate.ui.wizards.OperationWizardModel.OperationType;
import org.openide.DialogDisplayer;
import org.openide.NotifyDescriptor;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionRegistration;
import org.openide.util.NbBundle;
import org.openide.util.RequestProcessor;

@ActionID(id = "org.netbeans.modules.autoupdate.ui.actions.CheckForUpdatesAction", category = "System")
@ActionRegistration(displayName = "#CTL_CheckForUpdatesAction", iconInMenu=true)
@ActionReference(path = "Menu/Help", position = 1300)
public final class CheckForUpdatesAction implements ActionListener {

    @Override
    public void actionPerformed(ActionEvent ev) {
        boolean wizardFinished = false;
        RequestProcessor.Task t = PluginManagerUI.getRunningTask ();
        if (t != null && ! t.isFinished ()) {
            DialogDisplayer.getDefault ().notifyLater (
                    new NotifyDescriptor.Message (
                        NbBundle.getMessage (AutoupdateCheckScheduler.class,
                            "AutoupdateCheckScheduler_InstallInProgress"), // NOI18N
                        NotifyDescriptor.WARNING_MESSAGE));
            return ;
        }
        Collection<LazyUnit> units = LazyUnit.loadLazyUnits (OperationType.UPDATE);
        try {
            wizardFinished = new InstallUnitWizard ().invokeLazyWizard (units, OperationType.UPDATE, true);
        } finally {
            if (wizardFinished) {
                PluginManagerUI pluginManagerUI = PluginManagerAction.getPluginManagerUI ();
                if (pluginManagerUI != null) {
                    pluginManagerUI.updateUnitsChanged();
                }
            }
        }
    }
}
